==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-core/src/main/java/org/apache/geode/management/builder/GeodeClusterManagementServiceBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 *
 */

package org.apache.geode.management.builder;

import org.apache.geode.cache.GemFireCache;
import org.apache.geode.management.api.ConnectionConfig;
import org.apache.geode.management.internal.api.BaseManagementServiceBuilder;
import org.apache.geode.management.internal.api.GeodeConnectionConfig;

public class GeodeClusterManagementServiceBuilder
    extends BaseManagementServiceBuilder<GeodeClusterManagementServiceBuilder> {

  private GemFireCache cache;

  public GemFireCache getCache() {
    return cache;
  }

  public GeodeClusterManagementServiceBuilder setCache(GemFireCache cache) {
    this.cache = cache;
    return this;
  }

  protected ConnectionConfig createConnectionConfig() {
    return new GeodeConnectionConfig(cache);
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/main/java/org/apache/geode/management/builder/GeodeClusterManagementServiceBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 *
 */

package org.apache.geode.management.builder;

import org.apache.geode.cache.GemFireCache;
import org.apache.geode.management.api.ConnectionConfig;
import org.apache.geode.management.internal.api.GeodeConnectionConfig;
import org.apache.geode.management.service.internal.api.BaseManagementServiceBuilder;

public class GeodeClusterManagementServiceBuilder
    extends BaseManagementServiceBuilder<GeodeClusterManagementServiceBuilder> {

  private GemFireCache cache;

  public GemFireCache getCache() {
    return cache;
  }

  public GeodeClusterManagementServiceBuilder setCache(GemFireCache cache) {
    this.cache = cache;
    return this;
  }

  protected ConnectionConfig createConnectionConfig() {
    return new GeodeConnectionConfig(cache);
  }
}
